MessageBuilder

Struct MessageBuilder 

pub struct MessageBuilder { /* private fields */ }
MessageBuilder is the builder for Message.

Implementations

Source

impl MessageBuilder

pub fn builder() -> MessageBuilder

Create a new MessageBuilder for building a message. Read more

pub fn fifo_message_builder( topic: impl Into<String>, body: Vec<u8>, message_group: impl Into<String>, ) -> MessageBuilder

Create a new MessageBuilder for building a fifo message. Read more

Arguments
  • topic - topic of the message
  • body - message body
  • message_group - message group, messages with same message group will be delivered in FIFO order
pub fn delay_message_builder( topic: impl Into<String>, body: Vec<u8>, delay_time: i64, ) -> MessageBuilder

Create a new MessageBuilder for building a delay message. Read more

Arguments
  • topic - topic of the message
  • body - message body
  • delay_time - delivery timestamp of message, specify when to deliver the message
pub fn transaction_message_builder( topic: impl Into<String>, body: Vec<u8>, ) -> MessageBuilder

Create a new MessageBuilder for building a transaction message. Read more

Arguments
  • topic - topic of the message
  • body - message body
pub fn set_topic(self, topic: impl Into<String>) -> Self

Set topic for message, which is required

pub fn set_body(self, body: Vec<u8>) -> Self

Set message body, which is required

pub fn set_tag(self, tag: impl Into<String>) -> Self

Set message tag

pub fn set_keys(self, keys: Vec<impl Into<String>>) -> Self

Set message keys

pub fn set_properties( self, properties: HashMap<impl Into<String>, impl Into<String>>, ) -> Self

Set message properties

pub fn set_message_group(self, message_group: impl Into<String>) -> Self

Set message group, which is required for fifo message. Read more

The message group could not be set with delivery timestamp at the same time

pub fn set_delivery_timestamp(self, delivery_timestamp: i64) -> Self

Set delivery timestamp, which is required for delay message. Read more

The delivery timestamp could not be set with message group at the same time

pub fn enable_transaction(self) -> Self

Mark this message as the beginning transaction, which is required for the transaction message. Read more

The transaction message could not have message group and delivery timestamp

pub fn build(self) -> Result<impl Message, ClientError>

Build message