#[repr(i32)]pub enum TransactionResolution {
COMMIT = 1,
ROLLBACK = 2,
UNKNOWN = 0,
}Expand description
Resolution of Transaction.
Variants
COMMIT = 1
Notify server that current transaction should be committed.
ROLLBACK = 2
Notify server that current transaction should be roll-backed.
UNKNOWN = 0
Notify server that the state of this transaction is not sure. You should be cautious before return unknown because the examination from the server will be performed periodically.